@@ -19,6 +19,8 @@ pub mod nanoevery {
 
     pub timer0: &'static mut atmega4809::timer::tcb0::TimerImpl,
     pub timer1: &'static mut atmega4809::timer::tcb1::TimerImpl,
+    pub timer2: &'static mut atmega4809::timer::tcb2::TimerImpl,
+    pub timer3: &'static mut atmega4809::timer::tcb3::TimerImpl,
 
     pub a0: &'static mut atmega4809::port::portd::PinImpl,
     pub a1: &'static mut atmega4809::port::portd::PinImpl,
@@ -49,8 +51,10 @@ pub mod nanoevery {
   impl From<&'static mut crate::hal::atmega4809::hardware::Hardware> for Arduino {
     fn from(avr: &'static mut Hardware) -> Self {
       Arduino {
-        timer0: atmega4809::timer::tcb0::instance(),
-        timer1: atmega4809::timer::tcb1::instance(),
+        timer0: avr.timerb0,
+        timer1: avr.timerb1,
+        timer2: avr.timerb2,
+        timer3: avr.timerb3,
 
         a0: atmega4809::port::portd::pin_instance(3),
         a1: atmega4809::port::portd::pin_instance(2),
