@@ -9,12 +9,11 @@ use crate::hal::generic::timer::TimerControl;
 use crate::hal::generic::timer::TimerMode::Periodic;
 use crate::event::{EventSink, OxideEvent};
 
-use crate::deviceconsts::my::{ MASTER_CLOCK_PRESCALER, MASTER_CLOCK_HZ, MASTER_TICK_PERIOD_CS };
+use crate::deviceconsts::clock::{ MASTER_CLOCK_PRESCALER, MASTER_CLOCK_HZ, MASTER_TICK_FREQ_HZ };
+use static_assertions::const_assert;
 use core::marker::PhantomData;
 
 // Declarations ==============================================================
-
-
 pub struct MasterClock<T,S>
 where
   T: 'static + TimerControl,
@@ -27,18 +26,23 @@ where
 
 // Code ======================================================================
 
-impl<T,S> MasterClock<T,S>
+
+impl<T, S> MasterClock<T, S>
 where
   T: TimerControl,
   S: EventSink
 {
-  pub fn using_timer(timer: &'static mut T) -> Self {
-    const PERIPHERAL_CLOCK_HZ: u32  = MASTER_CLOCK_HZ/MASTER_CLOCK_PRESCALER as u32;
-    const TIMER_CLOCK_HZ: u32       = PERIPHERAL_CLOCK_HZ/2; // We use CLK_PER/2 in timer config
-    const CYCLES_PER_CS: u16        = (TIMER_CLOCK_HZ/100) as u16;
+
+
+  pub fn using_timer<const FREQ_HZ: u32>(timer: &'static mut T) -> Self {
+    const CYCLES_PER_TICK: u16       = (MASTER_CLOCK_HZ/(2 * MASTER_CLOCK_PRESCALER as u32 * MASTER_TICK_FREQ_HZ)) as u16; // We use CLK_PER/2 in timer config, hence the 2* term
+    const_assert!(CYCLES_PER_TICK > 10); // Sanity check really
+
+    debug_assert!(FREQ_HZ < MASTER_TICK_FREQ_HZ);
+    debug_assert!(FREQ_HZ > 0);
 
     Self {
-      timer: timer.mode(Periodic).count_max(CYCLES_PER_CS).interrupting(MASTER_TICK_PERIOD_CS),
+      timer: timer.mode(Periodic).count_max(CYCLES_PER_TICK).interrupting((MASTER_TICK_FREQ_HZ/FREQ_HZ) as u16),
       phantom: PhantomData::default()
     }
   }
