@@ -89,7 +89,7 @@ where
 
 // Code ======================================================================
 pub mod base {
-  use crate::hal::generic::port::{Port,InterruptMode};
+  use crate::hal::generic::port::InterruptMode;
 
   pub trait AtmelPortControl {
     /// Set this pin as an output.
@@ -252,7 +252,7 @@ pub mod base {
     ($ref:expr, $isr:ident) => {
       extern crate avr_device_snowgoons as avr_device;
 
-      use crate::hal::generic::port::{PinMode,Port,Pin,InterruptMode,PinInterruptHandler};
+      use crate::hal::generic::port::{PinMode,Pin,InterruptMode,PinInterruptHandler};
       use crate::hal::generic::port::base::{AtmelPortControl,AvrPortRegisterBlock};
 
       pub type PortImpl = AvrPortRegisterBlock;
