@@ -10,13 +10,17 @@
 #![feature(asm)]
 #![feature(global_asm)]
 #![feature(lang_items)]
+#![feature(concat_idents)]
+#![feature(maybe_uninit_uninit_array)]
+#![feature(maybe_uninit_extra)]
+
 
 #![cfg_attr(target_arch="avr", no_std)]
 
 pub mod devices;
 pub mod hal;
 pub mod event;
-pub mod supervisor;
+pub mod oxide;
 pub mod deviceconsts;
 mod mutstatic;
 mod ringq;
